# Generated by Django 4.2.1 on 2023-12-12 01:17

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('stela_control', '0008_alter_billingrecipt_option_alter_category_type_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='billingrecipt',
            name='option',
            field=models.CharField(choices=[('Billing receipt', 'Billing receipt'), ('Monthly charge', 'Monthly charge'), ('budget_design', 'Budget Design'), ('budget_marketing', 'Budget Marketing'), ('budget_development', 'Budget Development'), ('Others', 'Others')], max_length=60, null=True, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='company',
            name='business',
            field=models.CharField(blank=True, choices=[('Education and Training', 'Education and Training'), ('Logistics and Transportation Services', 'Logistics and Transportation Services'), ('E-commerce', 'E-commerce'), ('Media Creators', 'Media Creators'), ('Repair and Maintenance Services', 'Repair and Maintenance Services'), ('IT Development Services', 'IT Development Services'), ('Health and Wellness', 'Health and Wellness'), ('Consulting', 'Consulting'), ('Marketing and Advertising Services', 'Marketing and Advertising Services'), ('Beauty and Personal Care Services', 'Beauty and Personal Care Services'), ('Restaurants and Food Services', 'Restaurants and Food Services')], max_length=100, null=True, verbose_name='Business Type'),
        ),
        migrations.AlterField(
            model_name='content',
            name='card',
            field=models.CharField(blank=True, choices=[('card-light-danger', 'card-light-danger'), ('card-dark-blue', 'card-dark-blue'), ('card-tale', 'card-tale'), ('card-light-blue', 'card-light-blue')], max_length=50, null=True, verbose_name='Color Card'),
        ),
        migrations.AlterField(
            model_name='content',
            name='category',
            field=models.CharField(blank=True, choices=[('News', 'News'), ('Tutorials', 'Tutorials'), ('Inspiration', 'Inspiration'), ('Interviews', 'Interviews'), ('Events and Conferences', 'Events and Conferences'), ('Guides and Manuals', 'Guides and Manuals'), ('Tips and Tricks', 'Tips and Tricks')], default='News', max_length=100),
        ),
        migrations.AlterField(
            model_name='facebookpagecomments',
            name='update_rate',
            field=models.DateTimeField(default=datetime.datetime(2023, 12, 11, 22, 17, 21, 30676)),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='status',
            field=models.CharField(choices=[('Draft', 'Draft'), ('Send', 'Send')], max_length=20),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='template',
            field=models.CharField(choices=[('Style Template 3', 'Style Template 3'), ('Style Template 1', 'Style Template 1'), ('Style Template 4', 'Style Template 4'), ('Style Template 2', 'Style Template 2')], max_length=60, null=True, verbose_name='Style'),
        ),
        migrations.AlterField(
            model_name='order',
            name='section',
            field=models.CharField(choices=[('Cloud Domains', 'Cloud Domains'), ('Stela Design', 'Stela Design'), ('Stela Marketing', 'Stela Marketing'), ('No Selected', 'No Selected'), ('Store', 'Store'), ('Cloud Elastic Instance', 'Cloud Elastic Instance'), ('Stela Websites', 'Stela Websites')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='order',
            name='status',
            field=models.CharField(choices=[('Completed', 'Completed'), ('Pending', 'Pending')], default='Pending', max_length=100),
        ),
        migrations.AlterField(
            model_name='pathcontrol',
            name='step',
            field=models.CharField(choices=[('Step 2', 'Step 2'), ('Step 4', 'Step 4'), ('Step 3', 'Step 3')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='sendmoney',
            name='status',
            field=models.CharField(choices=[('Completed', 'Completed'), ('Pending', 'Pending')], default='Pending', max_length=50),
        ),
        migrations.AlterField(
            model_name='sitepolicy',
            name='section',
            field=models.CharField(blank=True, choices=[('Privacy Policy', 'Privacy Policy'), ('Cookie Policy', 'Cookie Policy'), ('billing_terms', 'Monthly Billing Terms'), ('budget_design_terms', 'Budget Design Terms'), ('Return Policy', 'Return Policy'), ('Terms and Conditions', 'Terms and Conditions'), ('Disclaimer', 'Disclaimer'), ('monthly_terms', 'Billing Terms'), ('budget_development_terms', 'Budget Development Terms'), ('budget_marketing_terms', 'Budget Marketing Terms')], default='Terms and Conditions', max_length=150),
        ),
        migrations.AlterField(
            model_name='sociallinks',
            name='social',
            field=models.CharField(choices=[('Tiktok', 'Tiktok'), ('Facebook', 'Facebook'), ('X', 'X'), ('Linkedin', 'Linkedin'), ('Instagram', 'Instagram'), ('Youtube', 'Youtube'), ('Github', 'Github')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='support',
            name='option',
            field=models.CharField(choices=[('I have a problem with my subscription', 'I have a problem with my subscription'), ('I have a problem with my project', 'I have a problem with my project'), ('Payments Issue', 'Payments Issue'), ('My account has an error', 'My account has an error'), ('My delivery has been delayed', 'My delivery has been delayed'), ('Others', 'Others')], max_length=60, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='support',
            name='status',
            field=models.CharField(choices=[('Completed', 'Completed'), ('Pending', 'Pending')], default='Pending', max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name='wallet',
            name='type',
            field=models.CharField(choices=[('Zelle', 'Zelle'), ('Paypal', 'Paypal'), ('Binance', 'Binance')], max_length=100, verbose_name='Type of Wallet'),
        ),
    ]



# Generated by Django 4.2.1 on 2023-12-08 18:14

import datetime
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('stela_control', '0006_facebookpageevent_lang_facebookpageevent_location_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='booking',
            name='user',
        ),
        migrations.AddField(
            model_name='booking',
            name='address',
            field=models.CharField(default='no address', max_length=250, verbose_name='billing_address'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='booking',
            name='created',
            field=models.DateTimeField(auto_now_add=True, default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='booking',
            name='email',
            field=models.EmailField(default='no email', max_length=254, verbose_name='email'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='booking',
            name='name',
            field=models.CharField(default='no name', max_length=250, verbose_name='name'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='booking',
            name='owner',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, related_name='bookings', to=settings.AUTH_USER_MODEL),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='booking',
            name='service',
            field=models.CharField(default='no service', max_length=250),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='booking',
            name='type',
            field=models.CharField(default='none', max_length=250),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='billingrecipt',
            name='option',
            field=models.CharField(choices=[('Monthly charge', 'Monthly charge'), ('budget_marketing', 'Budget Marketing'), ('Billing receipt', 'Billing receipt'), ('budget_design', 'Budget Design'), ('Others', 'Others'), ('budget_development', 'Budget Development')], max_length=60, null=True, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='company',
            name='business',
            field=models.CharField(blank=True, choices=[('IT Development Services', 'IT Development Services'), ('Repair and Maintenance Services', 'Repair and Maintenance Services'), ('Health and Wellness', 'Health and Wellness'), ('Media Creators', 'Media Creators'), ('Education and Training', 'Education and Training'), ('E-commerce', 'E-commerce'), ('Beauty and Personal Care Services', 'Beauty and Personal Care Services'), ('Consulting', 'Consulting'), ('Marketing and Advertising Services', 'Marketing and Advertising Services'), ('Logistics and Transportation Services', 'Logistics and Transportation Services'), ('Restaurants and Food Services', 'Restaurants and Food Services')], max_length=100, null=True, verbose_name='Business Type'),
        ),
        migrations.AlterField(
            model_name='content',
            name='card',
            field=models.CharField(blank=True, choices=[('card-light-danger', 'card-light-danger'), ('card-tale', 'card-tale'), ('card-light-blue', 'card-light-blue'), ('card-dark-blue', 'card-dark-blue')], max_length=50, null=True, verbose_name='Color Card'),
        ),
        migrations.AlterField(
            model_name='content',
            name='category',
            field=models.CharField(blank=True, choices=[('Inspiration', 'Inspiration'), ('Tutorials', 'Tutorials'), ('Events and Conferences', 'Events and Conferences'), ('Interviews', 'Interviews'), ('News', 'News'), ('Tips and Tricks', 'Tips and Tricks'), ('Guides and Manuals', 'Guides and Manuals')], default='News', max_length=100),
        ),
        migrations.AlterField(
            model_name='facebookpagecomments',
            name='update_rate',
            field=models.DateTimeField(default=datetime.datetime(2023, 12, 8, 15, 12, 37, 913144)),
        ),
        migrations.AlterField(
            model_name='itemdiscount',
            name='field',
            field=models.CharField(choices=[('Promotional Discount', 'Promotional Discount'), ('Initial Payment', 'Initial Payment'), ('No Selected', 'No Selected'), ('Stela Payment Free Suscription', 'Stela Payment Free Suscription')], max_length=60),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='status',
            field=models.CharField(choices=[('Draft', 'Draft'), ('Send', 'Send')], max_length=20),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='template',
            field=models.CharField(choices=[('Style Template 4', 'Style Template 4'), ('Style Template 1', 'Style Template 1'), ('Style Template 3', 'Style Template 3'), ('Style Template 2', 'Style Template 2')], max_length=60, null=True, verbose_name='Style'),
        ),
        migrations.AlterField(
            model_name='order',
            name='section',
            field=models.CharField(choices=[('Stela Websites', 'Stela Websites'), ('Stela Marketing', 'Stela Marketing'), ('Cloud Domains', 'Cloud Domains'), ('Stela Design', 'Stela Design'), ('Store', 'Store'), ('Cloud Elastic Instance', 'Cloud Elastic Instance'), ('No Selected', 'No Selected')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='pathcontrol',
            name='step',
            field=models.CharField(choices=[('Step 3', 'Step 3'), ('Step 4', 'Step 4'), ('Step 2', 'Step 2')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='sitepolicy',
            name='section',
            field=models.CharField(blank=True, choices=[('Cookie Policy', 'Cookie Policy'), ('billing_terms', 'Monthly Billing Terms'), ('Terms and Conditions', 'Terms and Conditions'), ('budget_design_terms', 'Budget Design Terms'), ('Disclaimer', 'Disclaimer'), ('budget_marketing_terms', 'Budget Marketing Terms'), ('Return Policy', 'Return Policy'), ('Privacy Policy', 'Privacy Policy'), ('budget_development_terms', 'Budget Development Terms'), ('monthly_terms', 'Billing Terms')], default='Terms and Conditions', max_length=150),
        ),
        migrations.AlterField(
            model_name='sociallinks',
            name='social',
            field=models.CharField(choices=[('Tiktok', 'Tiktok'), ('Youtube', 'Youtube'), ('X', 'X'), ('Facebook', 'Facebook'), ('Instagram', 'Instagram'), ('Linkedin', 'Linkedin'), ('Github', 'Github')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='support',
            name='option',
            field=models.CharField(choices=[('My account has an error', 'My account has an error'), ('I have a problem with my subscription', 'I have a problem with my subscription'), ('Others', 'Others'), ('I have a problem with my project', 'I have a problem with my project'), ('My delivery has been delayed', 'My delivery has been delayed'), ('Payments Issue', 'Payments Issue')], max_length=60, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='wallet',
            name='type',
            field=models.CharField(choices=[('Zelle', 'Zelle'), ('Paypal', 'Paypal'), ('Binance', 'Binance')], max_length=100, verbose_name='Type of Wallet'),
        ),
    ]



from django.urls import path, include
from . import views


    
app_name="siteapp"

urlpatterns = [
    path('', views.home, name="home"),
    #path('product-detail/<slug:slug>', views.product_detail, name="product_detail"),
    path('gallery/<int:id>', views.userGallery, name="user_gallery"),
    path('gallery/', views.gallery, name="gallery"),
    path('blog-detail/<slug:slug>', views.blog_detail, name="blog_detail"),
    #path('pricing', views.pricing, name="pricing"),
    path('contact', views.new_message, name="contact"),
    path('checkout', views.checkout, name="checkout"),
    #path('get-date/', views.getDate, name="get_date"),
    path('cart_add', views.cart_add, name="cart_add"),
    path('reorder', views.reorder, name="reorder"),
    # path('extra_add', views.extra_add, name="extra_add"),
    path('order-placed', views.order_placed, name="order-placed"),
    path('newsletter/suscribe/', views.newsletter, name="newsletter"),
    #docs
    path('about-us', views.aboutUs, name="about_us"),
    path('terms', views.terms, name="terms"),

]





# Generated by Django 4.2.1 on 2023-12-04 14:00

import datetime
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('stela_control', '0005_club_resource_alter_billingrecipt_option_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='facebookpageevent',
            name='lang',
            field=models.CharField(default='en', max_length=80),
        ),
        migrations.AddField(
            model_name='facebookpageevent',
            name='location',
            field=models.CharField(default='No location selected', max_length=250),
        ),
        migrations.AddField(
            model_name='facebookpageevent',
            name='owner',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, related_name='event_owner', to=settings.AUTH_USER_MODEL),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='billingrecipt',
            name='option',
            field=models.CharField(choices=[('budget_development', 'Budget Development'), ('Monthly charge', 'Monthly charge'), ('budget_design', 'Budget Design'), ('Others', 'Others'), ('Billing receipt', 'Billing receipt'), ('budget_marketing', 'Budget Marketing')], max_length=60, null=True, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='company',
            name='business',
            field=models.CharField(blank=True, choices=[('Education and Training', 'Education and Training'), ('IT Development Services', 'IT Development Services'), ('Marketing and Advertising Services', 'Marketing and Advertising Services'), ('Logistics and Transportation Services', 'Logistics and Transportation Services'), ('Repair and Maintenance Services', 'Repair and Maintenance Services'), ('Beauty and Personal Care Services', 'Beauty and Personal Care Services'), ('Media Creators', 'Media Creators'), ('E-commerce', 'E-commerce'), ('Consulting', 'Consulting'), ('Health and Wellness', 'Health and Wellness'), ('Restaurants and Food Services', 'Restaurants and Food Services')], max_length=100, null=True, verbose_name='Business Type'),
        ),
        migrations.AlterField(
            model_name='content',
            name='card',
            field=models.CharField(blank=True, choices=[('card-light-blue', 'card-light-blue'), ('card-tale', 'card-tale'), ('card-dark-blue', 'card-dark-blue'), ('card-light-danger', 'card-light-danger')], max_length=50, null=True, verbose_name='Color Card'),
        ),
        migrations.AlterField(
            model_name='content',
            name='category',
            field=models.CharField(blank=True, choices=[('Inspiration', 'Inspiration'), ('Guides and Manuals', 'Guides and Manuals'), ('Tips and Tricks', 'Tips and Tricks'), ('Events and Conferences', 'Events and Conferences'), ('Tutorials', 'Tutorials'), ('News', 'News'), ('Interviews', 'Interviews')], default='News', max_length=100),
        ),
        migrations.AlterField(
            model_name='facebookpagecomments',
            name='update_rate',
            field=models.DateTimeField(default=datetime.datetime(2023, 12, 4, 10, 59, 56, 624443)),
        ),
        migrations.AlterField(
            model_name='itemdiscount',
            name='field',
            field=models.CharField(choices=[('Initial Payment', 'Initial Payment'), ('Stela Payment Free Suscription', 'Stela Payment Free Suscription'), ('No Selected', 'No Selected'), ('Promotional Discount', 'Promotional Discount')], max_length=60),
        ),
        migrations.AlterField(
            model_name='newsletter',
            name='template',
            field=models.CharField(choices=[('Style Template 1', 'Style Template 1'), ('Style Template 3', 'Style Template 3'), ('Style Template 4', 'Style Template 4'), ('Style Template 2', 'Style Template 2')], max_length=60, null=True, verbose_name='Style'),
        ),
        migrations.AlterField(
            model_name='order',
            name='section',
            field=models.CharField(choices=[('Stela Websites', 'Stela Websites'), ('Cloud Domains', 'Cloud Domains'), ('No Selected', 'No Selected'), ('Stela Design', 'Stela Design'), ('Store', 'Store'), ('Stela Marketing', 'Stela Marketing'), ('Cloud Elastic Instance', 'Cloud Elastic Instance')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='order',
            name='status',
            field=models.CharField(choices=[('Pending', 'Pending'), ('Completed', 'Completed')], default='Pending', max_length=100),
        ),
        migrations.AlterField(
            model_name='pathcontrol',
            name='step',
            field=models.CharField(choices=[('Step 2', 'Step 2'), ('Step 3', 'Step 3'), ('Step 4', 'Step 4')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='sendmoney',
            name='status',
            field=models.CharField(choices=[('Pending', 'Pending'), ('Completed', 'Completed')], default='Pending', max_length=50),
        ),
        migrations.AlterField(
            model_name='sitepolicy',
            name='section',
            field=models.CharField(blank=True, choices=[('monthly_terms', 'Billing Terms'), ('budget_development_terms', 'Budget Development Terms'), ('budget_marketing_terms', 'Budget Marketing Terms'), ('billing_terms', 'Monthly Billing Terms'), ('Privacy Policy', 'Privacy Policy'), ('Disclaimer', 'Disclaimer'), ('Cookie Policy', 'Cookie Policy'), ('Terms and Conditions', 'Terms and Conditions'), ('Return Policy', 'Return Policy'), ('budget_design_terms', 'Budget Design Terms')], default='Terms and Conditions', max_length=150),
        ),
        migrations.AlterField(
            model_name='sociallinks',
            name='social',
            field=models.CharField(choices=[('Tiktok', 'Tiktok'), ('Instagram', 'Instagram'), ('Facebook', 'Facebook'), ('Youtube', 'Youtube'), ('Linkedin', 'Linkedin'), ('Github', 'Github'), ('X', 'X')], default='No Selected', max_length=50),
        ),
        migrations.AlterField(
            model_name='support',
            name='option',
            field=models.CharField(choices=[('My account has an error', 'My account has an error'), ('My delivery has been delayed', 'My delivery has been delayed'), ('I have a problem with my subscription', 'I have a problem with my subscription'), ('Payments Issue', 'Payments Issue'), ('I have a problem with my project', 'I have a problem with my project'), ('Others', 'Others')], max_length=60, verbose_name='Case'),
        ),
        migrations.AlterField(
            model_name='support',
            name='status',
            field=models.CharField(choices=[('Pending', 'Pending'), ('Completed', 'Completed')], default='Pending', max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name='wallet',
            name='type',
            field=models.CharField(choices=[('Binance', 'Binance'), ('Zelle', 'Zelle'), ('Paypal', 'Paypal')], max_length=100, verbose_name='Type of Wallet'),
        ),
    ]
